@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2016 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,6 @@ use NeedRestart::CONT;
 use Sort::Naturally;
 
 use constant {
-    NEEDRESTART_PRIO_NOAUTO	=> 0,
     NEEDRESTART_PRIO_LOW	=> 1,
     NEEDRESTART_PRIO_MEDIUM	=> 10,
     NEEDRESTART_PRIO_HIGH	=> 100,
@@ -42,13 +41,11 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
-    NEEDRESTART_PRIO_NOAUTO
     NEEDRESTART_PRIO_LOW
     NEEDRESTART_PRIO_MEDIUM
     NEEDRESTART_PRIO_HIGH
 
     needrestart_ui
-    needrestart_ui_list
     needrestart_interp_check
     needrestart_interp_source
     needrestart_cont_check
@@ -80,7 +77,7 @@ our %EXPORT_TAGS = (
     )],
 );
 
-our $VERSION = '2.11';
+our $VERSION = '2.6';
 my $LOGPREF = '[Core]';
 
 my %UIs;
@@ -96,7 +93,7 @@ sub needrestart_ui_init($$) {
     my $verbosity = shift;
     my $prefui = shift;
 
-    # load preferred UI module
+    # load prefered UI module
     if(defined($prefui)) {
 	return if(eval "use $prefui; 1;");
     }
@@ -114,9 +111,7 @@ sub needrestart_ui {
     my $prefui = shift;
 
     needrestart_ui_init($verbosity, $prefui) unless(%UIs);
-    my ($ui) = sort { ncmp($UIs{$b}, $UIs{$a}) } grep {
-	($UIs{$_} != NEEDRESTART_PRIO_NOAUTO) || ( defined($prefui) && ($prefui eq $_) )
-    } keys %UIs;
+    my ($ui) = sort { ncmp($UIs{$b}, $UIs{$a}) } keys %UIs;
 
     return undef unless($ui);
 
@@ -125,17 +120,8 @@ sub needrestart_ui {
     return $ui->new($verbosity);
 }
 
-sub needrestart_ui_list {
-    my $verbosity = shift;
-    my $prefui = shift;
-
-    needrestart_ui_init($verbosity, $prefui) unless(%UIs);
-    return (sort { ncmp($UIs{$b}, $UIs{$a}) } keys %UIs);
-}
-
 
 my %Interps;
-my %InterpCache;
 my $idebug;
 
 sub needrestart_interp_register($) {
@@ -155,11 +141,10 @@ sub needrestart_interp_init($) {
     }
 }
 
-sub needrestart_interp_check($$$$) {
+sub needrestart_interp_check($$$) {
     my $debug = shift;
     my $pid = shift;
     my $bin = shift;
-    my $blacklist = shift;
 
     needrestart_interp_init($debug) unless(%Interps);
 
@@ -168,13 +153,7 @@ sub needrestart_interp_check($$$$) {
 	    print STDERR "$LOGPREF #$pid is a ".(ref $interp)."\n" if($debug);
 
 	    my $ps = nr_ptable_pid($pid);
-	    my %files = $interp->files($pid, \%InterpCache);
-
-	    foreach my $path (keys %files) {
-		next unless(scalar grep { $path =~ /$_/; } @{$blacklist});
-		print  STDERR "$LOGPREF blacklisted: $path\n" if($debug);
-		delete($files{$path});
-	    }
+	    my %files = $interp->files($pid);
 
 	    if(grep {!defined($_) || $_ > $ps->start} values %files) {
 		if($debug) {
