@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -52,29 +52,15 @@ sub source {
     my $self = shift;
     my $pid = shift;
     my $ptable = nr_ptable_pid($pid);
-    unless($ptable->{cwd}) {
-	print STDERR "$LOGPREF #$pid: could not get current working directory, skipping\n" if($self->{debug});
-	return ();
-    }
     my $cwd = getcwd();
-    chdir("/proc/$pid/root/$ptable->{cwd}");
+    chdir($ptable->{cwd});
 
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
     # eat Perl's command line options
     my %opts;
-    {
-	local $SIG{__WARN__} = sub { };
-	getopts('sTtuUWXhvV:cwdt:D:pnaF:l:0:I:m:M:fC:Sx:i:eE:', \%opts);
-    }
-
-    # skip perl -e '...' calls
-    if(exists($opts{e}) || exists($opts{E})) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: uses no source file (-e), skipping\n" if($self->{debug});
-	return undef;
-    }
+    getopts('sTtuUWXhvV:cwdt:D:pnaF:l:0:I:m:M:fC:Sx:i:eE:', \%opts);
 
     # extract source file
     unless($#ARGV > -1) {
@@ -97,31 +83,20 @@ sub source {
 sub files {
     my $self = shift;
     my $pid = shift;
-    my $cache = shift;
     my $ptable = nr_ptable_pid($pid);
     unless($ptable->{cwd}) {
 	print STDERR "$LOGPREF #$pid: could not get current working directory, skipping\n" if($self->{debug});
 	return ();
     }
     my $cwd = getcwd();
-    chdir("/proc/$pid/root/$ptable->{cwd}");
+    chdir($ptable->{cwd});
 
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
     # eat Perl's command line options
     my %opts;
-    {
-	local $SIG{__WARN__} = sub { };
-	getopts('sTtuUWXhvV:cwdt:D:pnaF:l:0:I:m:M:fC:Sx:i:eE:', \%opts);
-    }
-
-    # skip perl -e '...' calls
-    if(exists($opts{e}) || exists($opts{E})) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: uses no source file (-e), skipping\n" if($self->{debug});
-	return ();
-    }
+    getopts('sTtuUWXhvV:cwdt:D:pnaF:l:0:I:m:M:fC:Sx:i:eE:', \%opts);
 
     # extract source file
     unless($#ARGV > -1) {
@@ -136,13 +111,6 @@ sub files {
 	print STDERR "$LOGPREF #$pid:  reduced ARGV: ".join(' ', @ARGV)."\n" if($self->{debug});
 	return ();
     }
-    print STDERR "$LOGPREF #$pid: source=$src\n" if($self->{debug});
-
-    # use cached data if avail
-    if(exists($cache->{files}->{(__PACKAGE__)}->{$src})) {
-	print STDERR "$LOGPREF #$pid: use cached file list\n" if($self->{debug});
-	return %{ $cache->{files}->{(__PACKAGE__)}->{$src} };
-    }
 
     # prepare include path environment variable
     my %e = nr_parse_env($pid);
@@ -155,25 +123,17 @@ sub files {
     }
 
     @Module::ScanDeps::IncludeLibs = (exists($opts{I}) ? ($opts{I}) : ());
-    my $href;
-    {
-	# Silence warnings of Module::ScanDeps for dynamic loaded modules (github issue #41)
-	local $SIG{__WARN__} = sub { };
-
-	$href = scan_deps(
-	    files => [$src],
-	    recurse => 1,
-	    );
-    }
+    my $href = scan_deps(
+	files => [$src],
+	recurse => 1,
+    );
 
     my %ret = map {
-	my $stat = nr_stat("/proc/$pid/root/$href->{$_}->{file}");
+	my $stat = nr_stat($href->{$_}->{file});
 	$href->{$_}->{file} => ( defined($stat) ? $stat->{ctime} : undef );
     } keys %$href;
 
     chdir($cwd);
-
-    $cache->{files}->{(__PACKAGE__)}->{$src} = \%ret;
     return %ret;
 }
 
