@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -88,24 +88,14 @@ sub source {
 	return ();
     }
     my $cwd = getcwd();
-    chdir("/proc/$pid/root/$ptable->{cwd}");
+    chdir($ptable->{cwd});
 
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
     # eat Python's command line options
     my %opts;
-    {
-	local $SIG{__WARN__} = sub { };
-	getopts('BdEhim:ORQ:sStuvVW:x3?c:', \%opts);
-    }
-
-    # skip python -c '...' calls
-    if(exists($opts{c})) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: uses no source file (-c), skipping\n" if($self->{debug});
-	return undef;
-    }
+    getopts('BdEhim:ORQ:sStuvVW:x3?c:', \%opts);
 
     # extract source file
     unless($#ARGV > -1) {
@@ -128,31 +118,16 @@ sub source {
 sub files {
     my $self = shift;
     my $pid = shift;
-    my $cache = shift;
     my $ptable = nr_ptable_pid($pid);
-    unless($ptable->{cwd}) {
-	print STDERR "$LOGPREF #$pid: could not get current working directory, skipping\n" if($self->{debug});
-	return ();
-    }
     my $cwd = getcwd();
-    chdir("/proc/$pid/root/$ptable->{cwd}");
+    chdir($ptable->{cwd});
 
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
     # eat Python's command line options
     my %opts;
-    {
-	local $SIG{__WARN__} = sub { };
-	getopts('BdEhim:ORQ:sStuvVW:x3?c:', \%opts);
-    }
-
-    # skip python -c '...' calls
-    if(exists($opts{c})) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: uses no source file (-c), skipping\n" if($self->{debug});
-	return ();
-    }
+    getopts('BdEhim:ORQ:sStuvVW:x3?c:', \%opts);
 
     # extract source file
     unless($#ARGV > -1) {
@@ -167,13 +142,6 @@ sub files {
 	print STDERR "$LOGPREF #$pid:  reduced ARGV: ".join(' ', @ARGV)."\n" if($self->{debug});
 	return ();
     }
-    print STDERR "$LOGPREF #$pid: source=$src\n" if($self->{debug});
-
-    # use cached data if avail
-    if(exists($cache->{files}->{(__PACKAGE__)}->{$src})) {
-	print STDERR "$LOGPREF #$pid: use cached file list\n" if($self->{debug});
-	return %{ $cache->{files}->{(__PACKAGE__)}->{$src} };
-    }
 
     # prepare include path environment variable
     my %e = nr_parse_env($pid);
@@ -198,7 +166,7 @@ sub files {
 	chomp($path);
 	$path =~ s/^\['//;
 	$path =~ s/'\$//;
-	@path = map { "/proc/$pid/root/$_"; } split("', '", $path);
+	@path = split("', '", $path);
     }
     else {
 	print STDERR "$LOGPREF #$pid: failed to retrieve include path\n" if($self->{debug});
@@ -208,13 +176,11 @@ sub files {
     _scan($self->{debug}, $pid, $src, \%files, \@path);
 
     my %ret = map {
-	my $stat = nr_stat("/proc/$pid/root/$_");
+	my $stat = nr_stat($_);
 	$_ => ( defined($stat) ? $stat->{ctime} : undef );
     } keys %files;
 
     chdir($cwd);
-
-    $cache->{files}->{(__PACKAGE__)}->{$src} = \%ret;
     return %ret;
 }
 
