@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -85,24 +85,14 @@ sub source {
 	return ();
     }
     my $cwd = getcwd();
-    chdir("/proc/$pid/root/$ptable->{cwd}");
+    chdir($ptable->{cwd});
 
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
     # eat Ruby's command line options
     my %opts;
-    {
-	local $SIG{__WARN__} = sub { };
-	getopts('SUacdlnpswvy0:C:E:F:I:K:T:W:e:i:r:x:e:d:', \%opts);
-    }
-
-    # skip ruby -e '...' calls
-    if(exists($opts{e})) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: uses no source file (-e), skipping\n" if($self->{debug});
-	return undef;
-    }
+    getopts('SUacdlnpswvy0:C:E:F:I:K:T:W:e:i:r:x:e:d:', \%opts);
 
     # extract source file
     unless($#ARGV > -1) {
@@ -125,31 +115,16 @@ sub source {
 sub files {
     my $self = shift;
     my $pid = shift;
-    my $cache = shift;
     my $ptable = nr_ptable_pid($pid);
-    unless($ptable->{cwd}) {
-	print STDERR "$LOGPREF #$pid: could not get current working directory, skipping\n" if($self->{debug});
-	return ();
-    }
     my $cwd = getcwd();
-    chdir("/proc/$pid/root/$ptable->{cwd}");
+    chdir($ptable->{cwd});
 
     # get original ARGV
     (my $bin, local @ARGV) = nr_parse_cmd($pid);
 
     # eat Ruby's command line options
     my %opts;
-    {
-	local $SIG{__WARN__} = sub { };
-	getopts('SUacdlnpswvy0:C:E:F:I:K:T:W:e:i:r:x:e:d:', \%opts);
-    }
-
-    # skip ruby -e '...' calls
-    if(exists($opts{e})) {
-	chdir($cwd);
-	print STDERR "$LOGPREF #$pid: uses no source file (-e), skipping\n" if($self->{debug});
-	return ();
-    }
+    getopts('SUacdlnpswvy0:C:E:F:I:K:T:W:e:i:r:x:e:d:', \%opts);
 
     # extract source file
     unless($#ARGV > -1) {
@@ -164,13 +139,6 @@ sub files {
 	print STDERR "$LOGPREF #$pid:  reduced ARGV: ".join(' ', @ARGV)."\n" if($self->{debug});
 	return ();
     }
-    print STDERR "$LOGPREF #$pid: source=$src\n" if($self->{debug});
-
-    # use cached data if avail
-    if(exists($cache->{files}->{(__PACKAGE__)}->{$src})) {
-	print STDERR "$LOGPREF #$pid: use cached file list\n" if($self->{debug});
-	return %{ $cache->{files}->{(__PACKAGE__)}->{$src} };
-    }
 
     # prepare include path environment variable
     my %e = nr_parse_env($pid);
@@ -184,7 +152,7 @@ sub files {
     
     # get include path
     my $rbread = nr_fork_pipe($self->{debug}, $ptable->{exec}, '-e', 'puts $:');
-    my @path = map { "/proc/$pid/root/$_"; } <$rbread>;
+    my @path = <$rbread>;
     close($rbread);
     chomp(@path);
 
@@ -192,13 +160,11 @@ sub files {
     _scan($self->{debug}, $pid, $src, \%files, \@path);
 
     my %ret = map {
-	my $stat = nr_stat("/proc/$pid/root/$_");
+	my $stat = nr_stat($_);
 	$_ => ( defined($stat) ? $stat->{ctime} : undef );
     } keys %files;
 
     chdir($cwd);
-
-    $cache->{files}->{(__PACKAGE__)}->{$src} = \%ret;
     return %ret;
 }
 
