@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,6 @@ use NeedRestart::Kernel;
 use NeedRestart::Strings;
 use POSIX qw(uname);
 use Sort::Naturally;
-use Locale::TextDomain 'needrestart';
 use Fcntl qw(SEEK_SET);
 
 use constant {
@@ -105,7 +104,6 @@ sub nr_linux_version_generic($$) {
 
     # fallback trying filename
     $fn =~ s/[^-]*-//;
-    $fn =~ s/\.img$//;
     if($fn =~ /^\d+\.\d+/) {
 	print STDERR "$LOGPREF version from filename: $fn\n" if($debug);
 
@@ -126,17 +124,11 @@ sub nr_kernel_check_real($$) {
 
     die "$LOGPREF Not running on Linux!\n" unless($sysname eq 'Linux');
 
-    my %kfiles = map {
-	$_ => 1,
-    } grep {
-	# filter initrd images
-	(!m@^/boot/init@);
-    } </boot/vmlinu* /boot/*.img>;
-
-    $ui->progress_prep(scalar keys %kfiles, __ 'Scanning linux images...');
+    my @kfiles = reverse nsort </boot/vmlinu*>;
+    $ui->progress_prep(scalar @kfiles, 'Scanning linux images...');
 
     my %kernels;
-    foreach my $fn (reverse nsort keys %kfiles) {
+    foreach my $fn (@kfiles) {
 	$ui->progress_step;
 	my $stat = nr_stat($fn);
 
@@ -166,7 +158,8 @@ sub nr_kernel_check_real($$) {
 
 	my $iversion = $verstr;
 	$iversion =~ s/^Linux version //;
-	$iversion =~ s/\s.+$//s;
+	chomp($iversion);
+	$iversion =~ s/\s.+$//;
 	$kernels{$iversion} = (index($verstr, $release) != -1 && index($verstr, $version) != -1);
 
 	print STDERR "$LOGPREF $fn => $verstr [$iversion]".($kernels{$iversion} ? '*' : '')."\n" if($debug);
