@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,6 @@ use NeedRestart::Kernel;
 use NeedRestart::Strings;
 use POSIX qw(uname);
 use Sort::Naturally;
-use Locale::TextDomain 'needrestart';
 
 my $LOGPREF = '[Kernel/kFreeBSD]';
 
@@ -46,7 +45,7 @@ sub nr_kernel_check_real($$) {
     die "$LOGPREF Not running on GNU/kFreeBSD!\n" unless($sysname eq 'GNU/kFreeBSD');
 
     my @kfiles = reverse nsort </boot/kfreebsd-*>;
-    $ui->progress_prep(scalar @kfiles, __ 'Scanning kfreebsd images...');
+    $ui->progress_prep(scalar @kfiles, 'Scanning kfreebsd images...');
 
     my %kernels;
     foreach my $fn (@kfiles) {
