@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,6 @@ package NeedRestart::UI;
 
 use strict;
 use warnings;
-use Text::Wrap qw(wrap $columns);
 use Term::ReadKey;
 
 sub new {
@@ -39,20 +38,6 @@ sub new {
     }, $class;
 }
 
-sub wprint {
-    my $self = shift;
-    my $fh = shift;
-    my $sp1 = shift;
-    my $sp2 = shift;
-    my $message = shift;
-
-    # workaround Debian Bug#824564 in Term::ReadKey: pass filehandle twice
-    my ($cols) = GetTerminalSize($fh, $fh);
-    $columns = $cols if($cols);
-
-    print $fh wrap($sp1, $sp2, $message);
-}
-
 sub progress_prep($$$) {
     my $self = shift;
     my ($max, $out) = @_;
@@ -156,24 +141,10 @@ sub notice($$) {
 }
 
 
-sub command() {
-   my $self = shift;
-
-   $self->notice(@_);
-}
-
-
 sub query_pkgs($$$$$) {
 }
 
 sub query_conts($$$$$) {
 }
 
-sub runcmd {
-    my $self = shift;
-    my $cb = shift;
-
-    &$cb;
-}
-
 1;
