@@ -4,7 +4,7 @@
 #   Thomas Liske <thomas@fiasko-nw.net>
 #
 # Copyright Holder:
-#   2013 - 2017 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
+#   2013 - 2015 (C) Thomas Liske [http://fiasko-nw.net/~thomas/]
 #
 # License:
 #   This program is free software; you can redistribute it and/or modify
@@ -29,19 +29,17 @@ use warnings;
 
 use parent qw(NeedRestart::UI);
 use NeedRestart qw(:ui);
-use Locale::TextDomain 'needrestart';
+
 
 needrestart_ui_register(__PACKAGE__, NEEDRESTART_PRIO_LOW);
 
+
 sub _announce {
     my $self = shift;
     my $message = shift;
     my %vars = @_;
 
-    $self->wprint(\*STDOUT, '', '', __x("Pending kernel upgrade!\n\nRunning kernel version:\n  {kversion}\n\nDiagnostics:\n  {message}\n\nRestarting the system to load the new kernel will not be handled automatically, so you should consider rebooting. [Return]\n",
-					 kversion => $vars{KVERSION},
-					 message => $message,
-		   ));
+    print "Pending kernel upgrade!\n\nRunning kernel version:\n  $vars{KVERSION}\n\nDiagnostics:\n  $message\n\nRestarting the system to load the new kernel will not be handled automatically, so you should consider rebooting. [Return]\n";
     <STDIN>;
 }
 
@@ -50,7 +48,7 @@ sub announce_abi {
     my $self = shift;
     my %vars = @_;
 
-    $self->_announce(__ 'The currently running kernel has an ABI compatible upgrade pending.', %vars);
+    $self->_announce('The currently running kernel has an ABI compatible upgrade pending.', %vars);
 }
 
 
@@ -58,41 +56,13 @@ sub announce_ver {
     my $self = shift;
     my %vars = @_;
 
-    $self->_announce(__x("The currently running kernel version is not the expected kernel version {eversion}.",
-			 eversion => $vars{EVERSION},
-		     ), %vars);
-}
-
-
-sub announce_ehint {
-    my $self = shift;
-    my %vars = @_;
-
-    $self->wprint(\*STDOUT, '', '', __x(<<EHINT, ehint => $vars{EHINT}));
-
-This system runs {ehint}. For more details, run «needrestart -m a».
-
-You should consider rebooting!
-
-EHINT
-
-    <STDIN>;
+    $self->_announce("The currently running kernel version is not the expected kernel version $vars{EVERSION}.", %vars);
 }
 
 
 sub notice($$) {
     my $self = shift;
     my $out = shift;
-    my $indent = ' ';
-    $indent .= $1 if($out =~ /^(\s+)/);
-
-    $self->wprint(\*STDOUT, '', $indent, "$out\n");
-}
-
-
-sub command {
-    my $self = shift;
-    my $out = shift;
 
     print "$out\n";
 }
@@ -105,14 +75,12 @@ sub _query($$) {
 
     my $i;
     do {
-	$self->wprint(\*STDOUT, '', '', "$query [" . ($def eq 'Y' ? 'Ynas?' : 'yNas?') . '] ');
+	print "$query [", ($def eq 'Y' ? 'Ynas?' : 'yNas?'), '] ';
 	if($self->{stdio_same}) {
 	    my $s = $self->{stdio_same};
-	    if($s eq 'auto') {
-		$s = ($def eq 'Y' ? 'yes' : 'no');
-	    }
+	    $s = ($def eq 'Y' ? 'yes' : 'no') if($s eq 'auto');
 
-	    print __($s), "\n";
+	    print "$s\n";
 	    return $s;
 	}
 
@@ -127,20 +95,17 @@ sub _query($$) {
 	$i =~ s/\s+$//;
 
 	if($i eq '?') {
-	    $self->wprint(\*STDOUT, '', '', __ <<HLP);
-  (Y)es  - restart this service
-  (N)o   - do not restart this service
-  (A)uto - auto restart all remaining services
-  (S)top - stop restarting services
+	    print <<HLP;
+  Yes   - restart this service
+  No    - do not restart this service
+  Auto  - auto restart all remaining services
+  Stop  - stop restarting services
 
 HLP
 	}
     } while(!( ($i) = map { (substr($_, 0, length($i)) eq $i ? ($_) : ())} @def ));
 
-    if($i eq 'auto') {
-	$self->{stdio_same} = 'auto';
-	return ($def eq 'Y' ? q(yes) : q(no));
-    }
+    return ($self->{stdio_same} = 'auto') if($i eq 'auto');
     return ($self->{stdio_same} = 'no') if($i eq 'stop');
 
     return $i;
@@ -156,12 +121,12 @@ sub query_pkgs($$$$$$) {
 
     delete($self->{stdio_same});
 
-    $self->wprint(\*STDOUT, '', '', "$out\n");
+    print "$out\n";
     foreach my $rc (sort keys %$pkgs) {
 	my ($or) = grep { $rc =~ /$_/; } keys %$overrides;
 	my $d = (defined($or) ? ($overrides->{$or} ? 'Y' : 'N') : ($def ? 'N' : 'Y'));
 
-	&$cb($rc) if($self->_query(__x('Restart «{rc}»?', rc => $rc), $d) eq 'yes');
+	&$cb($rc) if($self->_query("Restart $rc?", $d) eq 'yes');
     }
 }
 
